import typing_extensions

from synctera_client.paths import PathValues
from synctera_client.apis.paths.accounts import Accounts
from synctera_client.apis.paths.accounts_products import AccountsProducts
from synctera_client.apis.paths.accounts_products_product_id import AccountsProductsProductId
from synctera_client.apis.paths.accounts_templates import AccountsTemplates
from synctera_client.apis.paths.accounts_templates_template_id import AccountsTemplatesTemplateId
from synctera_client.apis.paths.accounts_account_id import AccountsAccountId
from synctera_client.apis.paths.accounts_account_id_relationships import AccountsAccountIdRelationships
from synctera_client.apis.paths.accounts_account_id_relationships_relationship_id import AccountsAccountIdRelationshipsRelationshipId
from synctera_client.apis.paths.ach import Ach
from synctera_client.apis.paths.ach_transaction_simulations_receiving_return import AchTransactionSimulationsReceivingReturn
from synctera_client.apis.paths.ach_transaction_simulations_receiving_transaction import AchTransactionSimulationsReceivingTransaction
from synctera_client.apis.paths.ach_transaction_id import AchTransactionId
from synctera_client.apis.paths.businesses import Businesses
from synctera_client.apis.paths.businesses_business_id import BusinessesBusinessId
from synctera_client.apis.paths.cards import Cards
from synctera_client.apis.paths.cards_activate import CardsActivate
from synctera_client.apis.paths.cards_card_widget_url import CardsCardWidgetUrl
from synctera_client.apis.paths.cards_digital_wallet_tokens import CardsDigitalWalletTokens
from synctera_client.apis.paths.cards_digital_wallet_tokens_digital_wallet_token_id import CardsDigitalWalletTokensDigitalWalletTokenId
from synctera_client.apis.paths.cards_gateways import CardsGateways
from synctera_client.apis.paths.cards_gateways_gateway_id import CardsGatewaysGatewayId
from synctera_client.apis.paths.cards_images import CardsImages
from synctera_client.apis.paths.cards_images_card_image_id import CardsImagesCardImageId
from synctera_client.apis.paths.cards_images_card_image_id_data import CardsImagesCardImageIdData
from synctera_client.apis.paths.cards_products import CardsProducts
from synctera_client.apis.paths.cards_single_use_token import CardsSingleUseToken
from synctera_client.apis.paths.cards_transaction_simulations_authorization import CardsTransactionSimulationsAuthorization
from synctera_client.apis.paths.cards_transaction_simulations_authorization_advice import CardsTransactionSimulationsAuthorizationAdvice
from synctera_client.apis.paths.cards_transaction_simulations_clearing import CardsTransactionSimulationsClearing
from synctera_client.apis.paths.cards_transaction_simulations_financial import CardsTransactionSimulationsFinancial
from synctera_client.apis.paths.cards_transaction_simulations_financial_advice import CardsTransactionSimulationsFinancialAdvice
from synctera_client.apis.paths.cards_transaction_simulations_financial_balance_inquiry import CardsTransactionSimulationsFinancialBalanceInquiry
from synctera_client.apis.paths.cards_transaction_simulations_financial_original_credit import CardsTransactionSimulationsFinancialOriginalCredit
from synctera_client.apis.paths.cards_transaction_simulations_financial_withdrawal import CardsTransactionSimulationsFinancialWithdrawal
from synctera_client.apis.paths.cards_transaction_simulations_reversal import CardsTransactionSimulationsReversal
from synctera_client.apis.paths.cards_card_id import CardsCardId
from synctera_client.apis.paths.cards_card_id_barcodes import CardsCardIdBarcodes
from synctera_client.apis.paths.cards_card_id_changes import CardsCardIdChanges
from synctera_client.apis.paths.cards_card_id_client_token import CardsCardIdClientToken
from synctera_client.apis.paths.cards_card_id_digital_wallet_tokens_applepay import CardsCardIdDigitalWalletTokensApplepay
from synctera_client.apis.paths.cards_card_id_digital_wallet_tokens_googlepay import CardsCardIdDigitalWalletTokensGooglepay
from synctera_client.apis.paths.cards_card_id_webhook_simulations_fulfillment import CardsCardIdWebhookSimulationsFulfillment
from synctera_client.apis.paths.cash_pickups import CashPickups
from synctera_client.apis.paths.cash_pickups_cash_pickup_id import CashPickupsCashPickupId
from synctera_client.apis.paths.customers import Customers
from synctera_client.apis.paths.customers_customer_id import CustomersCustomerId
from synctera_client.apis.paths.customers_customer_id_disclosures import CustomersCustomerIdDisclosures
from synctera_client.apis.paths.customers_customer_id_employment import CustomersCustomerIdEmployment
from synctera_client.apis.paths.customers_customer_id_employment_employment_id import CustomersCustomerIdEmploymentEmploymentId
from synctera_client.apis.paths.customers_customer_id_prefill import CustomersCustomerIdPrefill
from synctera_client.apis.paths.customers_customer_id_risk_ratings import CustomersCustomerIdRiskRatings
from synctera_client.apis.paths.customers_customer_id_risk_ratings_risk_rating_id import CustomersCustomerIdRiskRatingsRiskRatingId
from synctera_client.apis.paths.customers_customer_id_verifications import CustomersCustomerIdVerifications
from synctera_client.apis.paths.customers_customer_id_verifications_verification_id import CustomersCustomerIdVerificationsVerificationId
from synctera_client.apis.paths.customers_customer_id_verify import CustomersCustomerIdVerify
from synctera_client.apis.paths.customers_customer_id_watchlists_alerts import CustomersCustomerIdWatchlistsAlerts
from synctera_client.apis.paths.customers_customer_id_watchlists_alerts_alert_id import CustomersCustomerIdWatchlistsAlertsAlertId
from synctera_client.apis.paths.customers_customer_id_watchlists_subscriptions import CustomersCustomerIdWatchlistsSubscriptions
from synctera_client.apis.paths.customers_customer_id_watchlists_subscriptions_subscription_id import CustomersCustomerIdWatchlistsSubscriptionsSubscriptionId
from synctera_client.apis.paths.customers_customer_id_watchlists_suppressions import CustomersCustomerIdWatchlistsSuppressions
from synctera_client.apis.paths.disclosures import Disclosures
from synctera_client.apis.paths.disclosures_disclosure_id import DisclosuresDisclosureId
from synctera_client.apis.paths.documents import Documents
from synctera_client.apis.paths.documents_document_id import DocumentsDocumentId
from synctera_client.apis.paths.documents_document_id_contents import DocumentsDocumentIdContents
from synctera_client.apis.paths.documents_document_id_versions import DocumentsDocumentIdVersions
from synctera_client.apis.paths.documents_document_id_versions_document_version import DocumentsDocumentIdVersionsDocumentVersion
from synctera_client.apis.paths.documents_document_id_versions_document_version_contents import DocumentsDocumentIdVersionsDocumentVersionContents
from synctera_client.apis.paths.external_accounts import ExternalAccounts
from synctera_client.apis.paths.external_accounts_access_tokens import ExternalAccountsAccessTokens
from synctera_client.apis.paths.external_accounts_add_vendor_accounts import ExternalAccountsAddVendorAccounts
from synctera_client.apis.paths.external_accounts_link_tokens import ExternalAccountsLinkTokens
from synctera_client.apis.paths.external_accounts_sync_vendor_accounts import ExternalAccountsSyncVendorAccounts
from synctera_client.apis.paths.external_accounts_external_account_id import ExternalAccountsExternalAccountId
from synctera_client.apis.paths.external_accounts_external_account_id_balance import ExternalAccountsExternalAccountIdBalance
from synctera_client.apis.paths.external_accounts_external_account_id_transactions import ExternalAccountsExternalAccountIdTransactions
from synctera_client.apis.paths.external_cards import ExternalCards
from synctera_client.apis.paths.external_cards_tokens import ExternalCardsTokens
from synctera_client.apis.paths.external_cards_transfers import ExternalCardsTransfers
from synctera_client.apis.paths.external_cards_transfers_transfer_id import ExternalCardsTransfersTransferId
from synctera_client.apis.paths.external_cards_transfers_transfer_id_reversals import ExternalCardsTransfersTransferIdReversals
from synctera_client.apis.paths.external_cards_external_card_id import ExternalCardsExternalCardId
from synctera_client.apis.paths.internal_accounts import InternalAccounts
from synctera_client.apis.paths.internal_accounts_internal_account_id import InternalAccountsInternalAccountId
from synctera_client.apis.paths.monitoring_alerts import MonitoringAlerts
from synctera_client.apis.paths.monitoring_alerts_alert_id import MonitoringAlertsAlertId
from synctera_client.apis.paths.monitoring_subscriptions import MonitoringSubscriptions
from synctera_client.apis.paths.monitoring_subscriptions_subscription_id import MonitoringSubscriptionsSubscriptionId
from synctera_client.apis.paths.notes import Notes
from synctera_client.apis.paths.notes_note_id import NotesNoteId
from synctera_client.apis.paths.payment_schedules import PaymentSchedules
from synctera_client.apis.paths.payment_schedules_payments import PaymentSchedulesPayments
from synctera_client.apis.paths.payment_schedules_payment_schedule_id import PaymentSchedulesPaymentScheduleId
from synctera_client.apis.paths.persons import Persons
from synctera_client.apis.paths.persons_personal_ids import PersonsPersonalIds
from synctera_client.apis.paths.persons_personal_ids_personal_id_id import PersonsPersonalIdsPersonalIdId
from synctera_client.apis.paths.persons_person_id import PersonsPersonId
from synctera_client.apis.paths.persons_person_id_prefill import PersonsPersonIdPrefill
from synctera_client.apis.paths.rdc_deposits import RdcDeposits
from synctera_client.apis.paths.rdc_deposits_deposit_id import RdcDepositsDepositId
from synctera_client.apis.paths.relationships import Relationships
from synctera_client.apis.paths.relationships_relationship_id import RelationshipsRelationshipId
from synctera_client.apis.paths.spend_controls import SpendControls
from synctera_client.apis.paths.spend_controls_spend_control_id import SpendControlsSpendControlId
from synctera_client.apis.paths.statements import Statements
from synctera_client.apis.paths.statements_statement_id import StatementsStatementId
from synctera_client.apis.paths.statements_statement_id_transactions import StatementsStatementIdTransactions
from synctera_client.apis.paths.transactions_internal_transfer import TransactionsInternalTransfer
from synctera_client.apis.paths.transactions_internal_transfer_id import TransactionsInternalTransferId
from synctera_client.apis.paths.transactions_pending import TransactionsPending
from synctera_client.apis.paths.transactions_pending_id import TransactionsPendingId
from synctera_client.apis.paths.transactions_posted import TransactionsPosted
from synctera_client.apis.paths.transactions_posted_id import TransactionsPostedId
from synctera_client.apis.paths.verifications import Verifications
from synctera_client.apis.paths.verifications_adhoc import VerificationsAdhoc
from synctera_client.apis.paths.verifications_verify import VerificationsVerify
from synctera_client.apis.paths.verifications_verification_id import VerificationsVerificationId
from synctera_client.apis.paths.webhook_secrets import WebhookSecrets
from synctera_client.apis.paths.webhooks import Webhooks
from synctera_client.apis.paths.webhooks_trigger import WebhooksTrigger
from synctera_client.apis.paths.webhooks_webhook_id import WebhooksWebhookId
from synctera_client.apis.paths.webhooks_webhook_id_events import WebhooksWebhookIdEvents
from synctera_client.apis.paths.webhooks_webhook_id_events_event_id import WebhooksWebhookIdEventsEventId
from synctera_client.apis.paths.webhooks_webhook_id_events_event_id_resend import WebhooksWebhookIdEventsEventIdResend
from synctera_client.apis.paths.wipe import Wipe
from synctera_client.apis.paths.wires import Wires
from synctera_client.apis.paths.wires_wire_id import WiresWireId

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.ACCOUNTS: Accounts,
        PathValues.ACCOUNTS_PRODUCTS: AccountsProducts,
        PathValues.ACCOUNTS_PRODUCTS_PRODUCT_ID: AccountsProductsProductId,
        PathValues.ACCOUNTS_TEMPLATES: AccountsTemplates,
        PathValues.ACCOUNTS_TEMPLATES_TEMPLATE_ID: AccountsTemplatesTemplateId,
        PathValues.ACCOUNTS_ACCOUNT_ID: AccountsAccountId,
        PathValues.ACCOUNTS_ACCOUNT_ID_RELATIONSHIPS: AccountsAccountIdRelationships,
        PathValues.ACCOUNTS_ACCOUNT_ID_RELATIONSHIPS_RELATIONSHIP_ID: AccountsAccountIdRelationshipsRelationshipId,
        PathValues.ACH: Ach,
        PathValues.ACH_TRANSACTION_SIMULATIONS_RECEIVING_RETURN: AchTransactionSimulationsReceivingReturn,
        PathValues.ACH_TRANSACTION_SIMULATIONS_RECEIVING_TRANSACTION: AchTransactionSimulationsReceivingTransaction,
        PathValues.ACH_TRANSACTION_ID: AchTransactionId,
        PathValues.BUSINESSES: Businesses,
        PathValues.BUSINESSES_BUSINESS_ID: BusinessesBusinessId,
        PathValues.CARDS: Cards,
        PathValues.CARDS_ACTIVATE: CardsActivate,
        PathValues.CARDS_CARD_WIDGET_URL: CardsCardWidgetUrl,
        PathValues.CARDS_DIGITAL_WALLET_TOKENS: CardsDigitalWalletTokens,
        PathValues.CARDS_DIGITAL_WALLET_TOKENS_DIGITAL_WALLET_TOKEN_ID: CardsDigitalWalletTokensDigitalWalletTokenId,
        PathValues.CARDS_GATEWAYS: CardsGateways,
        PathValues.CARDS_GATEWAYS_GATEWAY_ID: CardsGatewaysGatewayId,
        PathValues.CARDS_IMAGES: CardsImages,
        PathValues.CARDS_IMAGES_CARD_IMAGE_ID: CardsImagesCardImageId,
        PathValues.CARDS_IMAGES_CARD_IMAGE_ID_DATA: CardsImagesCardImageIdData,
        PathValues.CARDS_PRODUCTS: CardsProducts,
        PathValues.CARDS_SINGLE_USE_TOKEN: CardsSingleUseToken,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_AUTHORIZATION: CardsTransactionSimulationsAuthorization,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_AUTHORIZATION_ADVICE: CardsTransactionSimulationsAuthorizationAdvice,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_CLEARING: CardsTransactionSimulationsClearing,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_FINANCIAL: CardsTransactionSimulationsFinancial,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_ADVICE: CardsTransactionSimulationsFinancialAdvice,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_BALANCE_INQUIRY: CardsTransactionSimulationsFinancialBalanceInquiry,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_ORIGINAL_CREDIT: CardsTransactionSimulationsFinancialOriginalCredit,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_WITHDRAWAL: CardsTransactionSimulationsFinancialWithdrawal,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_REVERSAL: CardsTransactionSimulationsReversal,
        PathValues.CARDS_CARD_ID: CardsCardId,
        PathValues.CARDS_CARD_ID_BARCODES: CardsCardIdBarcodes,
        PathValues.CARDS_CARD_ID_CHANGES: CardsCardIdChanges,
        PathValues.CARDS_CARD_ID_CLIENT_TOKEN: CardsCardIdClientToken,
        PathValues.CARDS_CARD_ID_DIGITAL_WALLET_TOKENS_APPLEPAY: CardsCardIdDigitalWalletTokensApplepay,
        PathValues.CARDS_CARD_ID_DIGITAL_WALLET_TOKENS_GOOGLEPAY: CardsCardIdDigitalWalletTokensGooglepay,
        PathValues.CARDS_CARD_ID_WEBHOOK_SIMULATIONS_FULFILLMENT: CardsCardIdWebhookSimulationsFulfillment,
        PathValues.CASH_PICKUPS: CashPickups,
        PathValues.CASH_PICKUPS_CASH_PICKUP_ID: CashPickupsCashPickupId,
        PathValues.CUSTOMERS: Customers,
        PathValues.CUSTOMERS_CUSTOMER_ID: CustomersCustomerId,
        PathValues.CUSTOMERS_CUSTOMER_ID_DISCLOSURES: CustomersCustomerIdDisclosures,
        PathValues.CUSTOMERS_CUSTOMER_ID_EMPLOYMENT: CustomersCustomerIdEmployment,
        PathValues.CUSTOMERS_CUSTOMER_ID_EMPLOYMENT_EMPLOYMENT_ID: CustomersCustomerIdEmploymentEmploymentId,
        PathValues.CUSTOMERS_CUSTOMER_ID_PREFILL: CustomersCustomerIdPrefill,
        PathValues.CUSTOMERS_CUSTOMER_ID_RISK_RATINGS: CustomersCustomerIdRiskRatings,
        PathValues.CUSTOMERS_CUSTOMER_ID_RISK_RATINGS_RISK_RATING_ID: CustomersCustomerIdRiskRatingsRiskRatingId,
        PathValues.CUSTOMERS_CUSTOMER_ID_VERIFICATIONS: CustomersCustomerIdVerifications,
        PathValues.CUSTOMERS_CUSTOMER_ID_VERIFICATIONS_VERIFICATION_ID: CustomersCustomerIdVerificationsVerificationId,
        PathValues.CUSTOMERS_CUSTOMER_ID_VERIFY: CustomersCustomerIdVerify,
        PathValues.CUSTOMERS_CUSTOMER_ID_WATCHLISTS_ALERTS: CustomersCustomerIdWatchlistsAlerts,
        PathValues.CUSTOMERS_CUSTOMER_ID_WATCHLISTS_ALERTS_ALERT_ID: CustomersCustomerIdWatchlistsAlertsAlertId,
        PathValues.CUSTOMERS_CUSTOMER_ID_WATCHLISTS_SUBSCRIPTIONS: CustomersCustomerIdWatchlistsSubscriptions,
        PathValues.CUSTOMERS_CUSTOMER_ID_WATCHLISTS_SUBSCRIPTIONS_SUBSCRIPTION_ID: CustomersCustomerIdWatchlistsSubscriptionsSubscriptionId,
        PathValues.CUSTOMERS_CUSTOMER_ID_WATCHLISTS_SUPPRESSIONS: CustomersCustomerIdWatchlistsSuppressions,
        PathValues.DISCLOSURES: Disclosures,
        PathValues.DISCLOSURES_DISCLOSURE_ID: DisclosuresDisclosureId,
        PathValues.DOCUMENTS: Documents,
        PathValues.DOCUMENTS_DOCUMENT_ID: DocumentsDocumentId,
        PathValues.DOCUMENTS_DOCUMENT_ID_CONTENTS: DocumentsDocumentIdContents,
        PathValues.DOCUMENTS_DOCUMENT_ID_VERSIONS: DocumentsDocumentIdVersions,
        PathValues.DOCUMENTS_DOCUMENT_ID_VERSIONS_DOCUMENT_VERSION: DocumentsDocumentIdVersionsDocumentVersion,
        PathValues.DOCUMENTS_DOCUMENT_ID_VERSIONS_DOCUMENT_VERSION_CONTENTS: DocumentsDocumentIdVersionsDocumentVersionContents,
        PathValues.EXTERNAL_ACCOUNTS: ExternalAccounts,
        PathValues.EXTERNAL_ACCOUNTS_ACCESS_TOKENS: ExternalAccountsAccessTokens,
        PathValues.EXTERNAL_ACCOUNTS_ADD_VENDOR_ACCOUNTS: ExternalAccountsAddVendorAccounts,
        PathValues.EXTERNAL_ACCOUNTS_LINK_TOKENS: ExternalAccountsLinkTokens,
        PathValues.EXTERNAL_ACCOUNTS_SYNC_VENDOR_ACCOUNTS: ExternalAccountsSyncVendorAccounts,
        PathValues.EXTERNAL_ACCOUNTS_EXTERNAL_ACCOUNT_ID: ExternalAccountsExternalAccountId,
        PathValues.EXTERNAL_ACCOUNTS_EXTERNAL_ACCOUNT_ID_BALANCE: ExternalAccountsExternalAccountIdBalance,
        PathValues.EXTERNAL_ACCOUNTS_EXTERNAL_ACCOUNT_ID_TRANSACTIONS: ExternalAccountsExternalAccountIdTransactions,
        PathValues.EXTERNAL_CARDS: ExternalCards,
        PathValues.EXTERNAL_CARDS_TOKENS: ExternalCardsTokens,
        PathValues.EXTERNAL_CARDS_TRANSFERS: ExternalCardsTransfers,
        PathValues.EXTERNAL_CARDS_TRANSFERS_TRANSFER_ID: ExternalCardsTransfersTransferId,
        PathValues.EXTERNAL_CARDS_TRANSFERS_TRANSFER_ID_REVERSALS: ExternalCardsTransfersTransferIdReversals,
        PathValues.EXTERNAL_CARDS_EXTERNAL_CARD_ID: ExternalCardsExternalCardId,
        PathValues.INTERNAL_ACCOUNTS: InternalAccounts,
        PathValues.INTERNAL_ACCOUNTS_INTERNAL_ACCOUNT_ID: InternalAccountsInternalAccountId,
        PathValues.MONITORING_ALERTS: MonitoringAlerts,
        PathValues.MONITORING_ALERTS_ALERT_ID: MonitoringAlertsAlertId,
        PathValues.MONITORING_SUBSCRIPTIONS: MonitoringSubscriptions,
        PathValues.MONITORING_SUBSCRIPTIONS_SUBSCRIPTION_ID: MonitoringSubscriptionsSubscriptionId,
        PathValues.NOTES: Notes,
        PathValues.NOTES_NOTE_ID: NotesNoteId,
        PathValues.PAYMENT_SCHEDULES: PaymentSchedules,
        PathValues.PAYMENT_SCHEDULES_PAYMENTS: PaymentSchedulesPayments,
        PathValues.PAYMENT_SCHEDULES_PAYMENT_SCHEDULE_ID: PaymentSchedulesPaymentScheduleId,
        PathValues.PERSONS: Persons,
        PathValues.PERSONS_PERSONAL_IDS: PersonsPersonalIds,
        PathValues.PERSONS_PERSONAL_IDS_PERSONAL_ID_ID: PersonsPersonalIdsPersonalIdId,
        PathValues.PERSONS_PERSON_ID: PersonsPersonId,
        PathValues.PERSONS_PERSON_ID_PREFILL: PersonsPersonIdPrefill,
        PathValues.RDC_DEPOSITS: RdcDeposits,
        PathValues.RDC_DEPOSITS_DEPOSIT_ID: RdcDepositsDepositId,
        PathValues.RELATIONSHIPS: Relationships,
        PathValues.RELATIONSHIPS_RELATIONSHIP_ID: RelationshipsRelationshipId,
        PathValues.SPEND_CONTROLS: SpendControls,
        PathValues.SPEND_CONTROLS_SPEND_CONTROL_ID: SpendControlsSpendControlId,
        PathValues.STATEMENTS: Statements,
        PathValues.STATEMENTS_STATEMENT_ID: StatementsStatementId,
        PathValues.STATEMENTS_STATEMENT_ID_TRANSACTIONS: StatementsStatementIdTransactions,
        PathValues.TRANSACTIONS_INTERNAL_TRANSFER: TransactionsInternalTransfer,
        PathValues.TRANSACTIONS_INTERNAL_TRANSFER_ID: TransactionsInternalTransferId,
        PathValues.TRANSACTIONS_PENDING: TransactionsPending,
        PathValues.TRANSACTIONS_PENDING_ID: TransactionsPendingId,
        PathValues.TRANSACTIONS_POSTED: TransactionsPosted,
        PathValues.TRANSACTIONS_POSTED_ID: TransactionsPostedId,
        PathValues.VERIFICATIONS: Verifications,
        PathValues.VERIFICATIONS_ADHOC: VerificationsAdhoc,
        PathValues.VERIFICATIONS_VERIFY: VerificationsVerify,
        PathValues.VERIFICATIONS_VERIFICATION_ID: VerificationsVerificationId,
        PathValues.WEBHOOK_SECRETS: WebhookSecrets,
        PathValues.WEBHOOKS: Webhooks,
        PathValues.WEBHOOKS_TRIGGER: WebhooksTrigger,
        PathValues.WEBHOOKS_WEBHOOK_ID: WebhooksWebhookId,
        PathValues.WEBHOOKS_WEBHOOK_ID_EVENTS: WebhooksWebhookIdEvents,
        PathValues.WEBHOOKS_WEBHOOK_ID_EVENTS_EVENT_ID: WebhooksWebhookIdEventsEventId,
        PathValues.WEBHOOKS_WEBHOOK_ID_EVENTS_EVENT_ID_RESEND: WebhooksWebhookIdEventsEventIdResend,
        PathValues.WIPE: Wipe,
        PathValues.WIRES: Wires,
        PathValues.WIRES_WIRE_ID: WiresWireId,
    }
)

path_to_api = PathToApi(
    {
        PathValues.ACCOUNTS: Accounts,
        PathValues.ACCOUNTS_PRODUCTS: AccountsProducts,
        PathValues.ACCOUNTS_PRODUCTS_PRODUCT_ID: AccountsProductsProductId,
        PathValues.ACCOUNTS_TEMPLATES: AccountsTemplates,
        PathValues.ACCOUNTS_TEMPLATES_TEMPLATE_ID: AccountsTemplatesTemplateId,
        PathValues.ACCOUNTS_ACCOUNT_ID: AccountsAccountId,
        PathValues.ACCOUNTS_ACCOUNT_ID_RELATIONSHIPS: AccountsAccountIdRelationships,
        PathValues.ACCOUNTS_ACCOUNT_ID_RELATIONSHIPS_RELATIONSHIP_ID: AccountsAccountIdRelationshipsRelationshipId,
        PathValues.ACH: Ach,
        PathValues.ACH_TRANSACTION_SIMULATIONS_RECEIVING_RETURN: AchTransactionSimulationsReceivingReturn,
        PathValues.ACH_TRANSACTION_SIMULATIONS_RECEIVING_TRANSACTION: AchTransactionSimulationsReceivingTransaction,
        PathValues.ACH_TRANSACTION_ID: AchTransactionId,
        PathValues.BUSINESSES: Businesses,
        PathValues.BUSINESSES_BUSINESS_ID: BusinessesBusinessId,
        PathValues.CARDS: Cards,
        PathValues.CARDS_ACTIVATE: CardsActivate,
        PathValues.CARDS_CARD_WIDGET_URL: CardsCardWidgetUrl,
        PathValues.CARDS_DIGITAL_WALLET_TOKENS: CardsDigitalWalletTokens,
        PathValues.CARDS_DIGITAL_WALLET_TOKENS_DIGITAL_WALLET_TOKEN_ID: CardsDigitalWalletTokensDigitalWalletTokenId,
        PathValues.CARDS_GATEWAYS: CardsGateways,
        PathValues.CARDS_GATEWAYS_GATEWAY_ID: CardsGatewaysGatewayId,
        PathValues.CARDS_IMAGES: CardsImages,
        PathValues.CARDS_IMAGES_CARD_IMAGE_ID: CardsImagesCardImageId,
        PathValues.CARDS_IMAGES_CARD_IMAGE_ID_DATA: CardsImagesCardImageIdData,
        PathValues.CARDS_PRODUCTS: CardsProducts,
        PathValues.CARDS_SINGLE_USE_TOKEN: CardsSingleUseToken,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_AUTHORIZATION: CardsTransactionSimulationsAuthorization,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_AUTHORIZATION_ADVICE: CardsTransactionSimulationsAuthorizationAdvice,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_CLEARING: CardsTransactionSimulationsClearing,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_FINANCIAL: CardsTransactionSimulationsFinancial,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_ADVICE: CardsTransactionSimulationsFinancialAdvice,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_BALANCE_INQUIRY: CardsTransactionSimulationsFinancialBalanceInquiry,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_ORIGINAL_CREDIT: CardsTransactionSimulationsFinancialOriginalCredit,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_FINANCIAL_WITHDRAWAL: CardsTransactionSimulationsFinancialWithdrawal,
        PathValues.CARDS_TRANSACTION_SIMULATIONS_REVERSAL: CardsTransactionSimulationsReversal,
        PathValues.CARDS_CARD_ID: CardsCardId,
        PathValues.CARDS_CARD_ID_BARCODES: CardsCardIdBarcodes,
        PathValues.CARDS_CARD_ID_CHANGES: CardsCardIdChanges,
        PathValues.CARDS_CARD_ID_CLIENT_TOKEN: CardsCardIdClientToken,
        PathValues.CARDS_CARD_ID_DIGITAL_WALLET_TOKENS_APPLEPAY: CardsCardIdDigitalWalletTokensApplepay,
        PathValues.CARDS_CARD_ID_DIGITAL_WALLET_TOKENS_GOOGLEPAY: CardsCardIdDigitalWalletTokensGooglepay,
        PathValues.CARDS_CARD_ID_WEBHOOK_SIMULATIONS_FULFILLMENT: CardsCardIdWebhookSimulationsFulfillment,
        PathValues.CASH_PICKUPS: CashPickups,
        PathValues.CASH_PICKUPS_CASH_PICKUP_ID: CashPickupsCashPickupId,
        PathValues.CUSTOMERS: Customers,
        PathValues.CUSTOMERS_CUSTOMER_ID: CustomersCustomerId,
        PathValues.CUSTOMERS_CUSTOMER_ID_DISCLOSURES: CustomersCustomerIdDisclosures,
        PathValues.CUSTOMERS_CUSTOMER_ID_EMPLOYMENT: CustomersCustomerIdEmployment,
        PathValues.CUSTOMERS_CUSTOMER_ID_EMPLOYMENT_EMPLOYMENT_ID: CustomersCustomerIdEmploymentEmploymentId,
        PathValues.CUSTOMERS_CUSTOMER_ID_PREFILL: CustomersCustomerIdPrefill,
        PathValues.CUSTOMERS_CUSTOMER_ID_RISK_RATINGS: CustomersCustomerIdRiskRatings,
        PathValues.CUSTOMERS_CUSTOMER_ID_RISK_RATINGS_RISK_RATING_ID: CustomersCustomerIdRiskRatingsRiskRatingId,
        PathValues.CUSTOMERS_CUSTOMER_ID_VERIFICATIONS: CustomersCustomerIdVerifications,
        PathValues.CUSTOMERS_CUSTOMER_ID_VERIFICATIONS_VERIFICATION_ID: CustomersCustomerIdVerificationsVerificationId,
        PathValues.CUSTOMERS_CUSTOMER_ID_VERIFY: CustomersCustomerIdVerify,
        PathValues.CUSTOMERS_CUSTOMER_ID_WATCHLISTS_ALERTS: CustomersCustomerIdWatchlistsAlerts,
        PathValues.CUSTOMERS_CUSTOMER_ID_WATCHLISTS_ALERTS_ALERT_ID: CustomersCustomerIdWatchlistsAlertsAlertId,
        PathValues.CUSTOMERS_CUSTOMER_ID_WATCHLISTS_SUBSCRIPTIONS: CustomersCustomerIdWatchlistsSubscriptions,
        PathValues.CUSTOMERS_CUSTOMER_ID_WATCHLISTS_SUBSCRIPTIONS_SUBSCRIPTION_ID: CustomersCustomerIdWatchlistsSubscriptionsSubscriptionId,
        PathValues.CUSTOMERS_CUSTOMER_ID_WATCHLISTS_SUPPRESSIONS: CustomersCustomerIdWatchlistsSuppressions,
        PathValues.DISCLOSURES: Disclosures,
        PathValues.DISCLOSURES_DISCLOSURE_ID: DisclosuresDisclosureId,
        PathValues.DOCUMENTS: Documents,
        PathValues.DOCUMENTS_DOCUMENT_ID: DocumentsDocumentId,
        PathValues.DOCUMENTS_DOCUMENT_ID_CONTENTS: DocumentsDocumentIdContents,
        PathValues.DOCUMENTS_DOCUMENT_ID_VERSIONS: DocumentsDocumentIdVersions,
        PathValues.DOCUMENTS_DOCUMENT_ID_VERSIONS_DOCUMENT_VERSION: DocumentsDocumentIdVersionsDocumentVersion,
        PathValues.DOCUMENTS_DOCUMENT_ID_VERSIONS_DOCUMENT_VERSION_CONTENTS: DocumentsDocumentIdVersionsDocumentVersionContents,
        PathValues.EXTERNAL_ACCOUNTS: ExternalAccounts,
        PathValues.EXTERNAL_ACCOUNTS_ACCESS_TOKENS: ExternalAccountsAccessTokens,
        PathValues.EXTERNAL_ACCOUNTS_ADD_VENDOR_ACCOUNTS: ExternalAccountsAddVendorAccounts,
        PathValues.EXTERNAL_ACCOUNTS_LINK_TOKENS: ExternalAccountsLinkTokens,
        PathValues.EXTERNAL_ACCOUNTS_SYNC_VENDOR_ACCOUNTS: ExternalAccountsSyncVendorAccounts,
        PathValues.EXTERNAL_ACCOUNTS_EXTERNAL_ACCOUNT_ID: ExternalAccountsExternalAccountId,
        PathValues.EXTERNAL_ACCOUNTS_EXTERNAL_ACCOUNT_ID_BALANCE: ExternalAccountsExternalAccountIdBalance,
        PathValues.EXTERNAL_ACCOUNTS_EXTERNAL_ACCOUNT_ID_TRANSACTIONS: ExternalAccountsExternalAccountIdTransactions,
        PathValues.EXTERNAL_CARDS: ExternalCards,
        PathValues.EXTERNAL_CARDS_TOKENS: ExternalCardsTokens,
        PathValues.EXTERNAL_CARDS_TRANSFERS: ExternalCardsTransfers,
        PathValues.EXTERNAL_CARDS_TRANSFERS_TRANSFER_ID: ExternalCardsTransfersTransferId,
        PathValues.EXTERNAL_CARDS_TRANSFERS_TRANSFER_ID_REVERSALS: ExternalCardsTransfersTransferIdReversals,
        PathValues.EXTERNAL_CARDS_EXTERNAL_CARD_ID: ExternalCardsExternalCardId,
        PathValues.INTERNAL_ACCOUNTS: InternalAccounts,
        PathValues.INTERNAL_ACCOUNTS_INTERNAL_ACCOUNT_ID: InternalAccountsInternalAccountId,
        PathValues.MONITORING_ALERTS: MonitoringAlerts,
        PathValues.MONITORING_ALERTS_ALERT_ID: MonitoringAlertsAlertId,
        PathValues.MONITORING_SUBSCRIPTIONS: MonitoringSubscriptions,
        PathValues.MONITORING_SUBSCRIPTIONS_SUBSCRIPTION_ID: MonitoringSubscriptionsSubscriptionId,
        PathValues.NOTES: Notes,
        PathValues.NOTES_NOTE_ID: NotesNoteId,
        PathValues.PAYMENT_SCHEDULES: PaymentSchedules,
        PathValues.PAYMENT_SCHEDULES_PAYMENTS: PaymentSchedulesPayments,
        PathValues.PAYMENT_SCHEDULES_PAYMENT_SCHEDULE_ID: PaymentSchedulesPaymentScheduleId,
        PathValues.PERSONS: Persons,
        PathValues.PERSONS_PERSONAL_IDS: PersonsPersonalIds,
        PathValues.PERSONS_PERSONAL_IDS_PERSONAL_ID_ID: PersonsPersonalIdsPersonalIdId,
        PathValues.PERSONS_PERSON_ID: PersonsPersonId,
        PathValues.PERSONS_PERSON_ID_PREFILL: PersonsPersonIdPrefill,
        PathValues.RDC_DEPOSITS: RdcDeposits,
        PathValues.RDC_DEPOSITS_DEPOSIT_ID: RdcDepositsDepositId,
        PathValues.RELATIONSHIPS: Relationships,
        PathValues.RELATIONSHIPS_RELATIONSHIP_ID: RelationshipsRelationshipId,
        PathValues.SPEND_CONTROLS: SpendControls,
        PathValues.SPEND_CONTROLS_SPEND_CONTROL_ID: SpendControlsSpendControlId,
        PathValues.STATEMENTS: Statements,
        PathValues.STATEMENTS_STATEMENT_ID: StatementsStatementId,
        PathValues.STATEMENTS_STATEMENT_ID_TRANSACTIONS: StatementsStatementIdTransactions,
        PathValues.TRANSACTIONS_INTERNAL_TRANSFER: TransactionsInternalTransfer,
        PathValues.TRANSACTIONS_INTERNAL_TRANSFER_ID: TransactionsInternalTransferId,
        PathValues.TRANSACTIONS_PENDING: TransactionsPending,
        PathValues.TRANSACTIONS_PENDING_ID: TransactionsPendingId,
        PathValues.TRANSACTIONS_POSTED: TransactionsPosted,
        PathValues.TRANSACTIONS_POSTED_ID: TransactionsPostedId,
        PathValues.VERIFICATIONS: Verifications,
        PathValues.VERIFICATIONS_ADHOC: VerificationsAdhoc,
        PathValues.VERIFICATIONS_VERIFY: VerificationsVerify,
        PathValues.VERIFICATIONS_VERIFICATION_ID: VerificationsVerificationId,
        PathValues.WEBHOOK_SECRETS: WebhookSecrets,
        PathValues.WEBHOOKS: Webhooks,
        PathValues.WEBHOOKS_TRIGGER: WebhooksTrigger,
        PathValues.WEBHOOKS_WEBHOOK_ID: WebhooksWebhookId,
        PathValues.WEBHOOKS_WEBHOOK_ID_EVENTS: WebhooksWebhookIdEvents,
        PathValues.WEBHOOKS_WEBHOOK_ID_EVENTS_EVENT_ID: WebhooksWebhookIdEventsEventId,
        PathValues.WEBHOOKS_WEBHOOK_ID_EVENTS_EVENT_ID_RESEND: WebhooksWebhookIdEventsEventIdResend,
        PathValues.WIPE: Wipe,
        PathValues.WIRES: Wires,
        PathValues.WIRES_WIRE_ID: WiresWireId,
    }
)



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from synctera_client.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    ACCOUNT_PRODUCTS = "Account Products"
    ACCOUNTS = "Accounts"
    ACCOUNT_TEMPLATES = "Account Templates"
    ACH = "ACH"
    ACH_TRANSACTION_SIMULATIONS = "ACH Transaction Simulations"
    ADMIN = "Admin"
    API_KEYS = "API Keys"
    BAN_RULES = "Ban Rules"
    BANKS = "Banks"
    QUICKSTART = "Quickstart"
    BUSINESSES = "Businesses"
    CARDS = "Cards"
    EXTERNAL_CARDS = "External Cards"
    CASH_PICKUPS_ALPHA = "Cash Pickups (alpha)"
    COMPLIANCE_RULES = "Compliance Rules"
    COMPLIANCE_SEARCHES = "Compliance Searches"
    CUSTOMERS = "Customers"
    DISCLOSURES = "Disclosures"
    DISCLOSURES_DEPRECATED = "Disclosures (deprecated)"
    DOCUMENTS = "Documents"
    STATELY = "Stately"
    EXTERNAL_ACCOUNTS = "External Accounts"
    HISTORY = "History"
    IDENTITY = "Identity"
    INTERNAL_ACCOUNTS = "Internal Accounts"
    KYC_VERIFICATION_DEPRECATED = "KYC Verification (deprecated)"
    MIDDESK = "Middesk"
    MONITORING = "Monitoring"
    NOTES = "Notes"
    PARTNERS = "Partners"
    PARTY_GROUPS = "Party Groups"
    CRONUT = "Cronut"
    PERSONS = "Persons"
    POSTING_DATES = "Posting Dates"
    REMOTE_CHECK_DEPOSIT = "Remote Check Deposit"
    RDC_CONFIG = "RDC Config"
    RELATIONSHIPS = "Relationships"
    ROLES = "Roles"
    SPEND_CONTROLS_BETA = "Spend Controls (beta)"
    TENANT_CONFIGS = "Tenant Configs"
    CARD_TRANSACTION_SIMULATIONS = "Card Transaction Simulations"
    TRANSACTION_RISK = "Transaction risk"
    TRANSACTIONS = "Transactions"
    USERS = "Users"
    EGRESS_GATEWAY_VENDOR_SECRET_CRUD_API = "Egress Gateway Vendor Secret CRUD API"
    KYC_KYB_VERIFICATIONS = "KYC/KYB Verifications"
    WAITLIST = "Waitlist"
    WATCHLIST_DEPRECATED = "Watchlist (deprecated)"
    EGRESS_GATEWAY_WEBHOOK_SECRET_CRUD_API = "Egress Gateway Webhook Secret CRUD API"
    CARD_WEBHOOK_SIMULATIONS = "Card Webhook Simulations"
    WEBHOOKS = "Webhooks"
    WIRES_ALPHA = "Wires (alpha)"
    DIGITAL_WALLET_TOKENS = "Digital Wallet Tokens"
    INTERNAL_TRANSFER = "Internal Transfer"
    PAYMENT_SCHEDULES = "PaymentSchedules"
    REMOTE_CHECK_DEPOSIT_BETA = "Remote Check Deposit (beta)"
    SANDBOX_WIPE_ALPHA = "Sandbox Wipe (alpha)"
    STATEMENTS = "Statements"



from synctera_client.paths.customers_customer_id_watchlists_subscriptions.get import ApiForget
from synctera_client.paths.customers_customer_id_watchlists_subscriptions.post import ApiForpost


class CustomersCustomerIdWatchlistsSubscriptions(
    ApiForget,
    ApiForpost,
):
    pass



from synctera_client.paths.external_accounts.get import ApiForget
from synctera_client.paths.external_accounts.post import ApiForpost


class ExternalAccounts(
    ApiForget,
    ApiForpost,
):
    pass



from synctera_client.paths.customers_customer_id_risk_ratings.get import ApiForget
from synctera_client.paths.customers_customer_id_risk_ratings.post import ApiForpost


class CustomersCustomerIdRiskRatings(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class WebhookRequestObject(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Request body for webhook http request
    """


    class MetaOapg:
        required = {
            "metadata",
            "webhook_id",
            "id",
            "type",
            "event_time",
            "url",
        }
        
        class properties:
            event_time = schemas.DateTimeSchema
            id = schemas.UUIDSchema
            
            
            class metadata(
                schemas.StrSchema
            ):
                pass
        
            @staticmethod
            def type() -> typing.Type['EventTypeExplicit']:
                return EventTypeExplicit
            
            
            class url(
                schemas.StrSchema
            ):
                pass
            webhook_id = schemas.UUIDSchema
            event_resource = schemas.StrSchema
            event_resource_changed_fields = schemas.StrSchema
            
            
            class response_history(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ResponseHistoryItem']:
                        return ResponseHistoryItem
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['ResponseHistoryItem'], typing.List['ResponseHistoryItem']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'response_history':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ResponseHistoryItem':
                    return super().__getitem__(i)
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def RUNNING(cls):
                    return cls("RUNNING")
                
                @schemas.classproperty
                def SUCCESS(cls):
                    return cls("SUCCESS")
                
                @schemas.classproperty
                def RETRYING(cls):
                    return cls("RETRYING")
                
                @schemas.classproperty
                def FAILED(cls):
                    return cls("FAILED")
            __annotations__ = {
                "event_time": event_time,
                "id": id,
                "metadata": metadata,
                "type": type,
                "url": url,
                "webhook_id": webhook_id,
                "event_resource": event_resource,
                "event_resource_changed_fields": event_resource_changed_fields,
                "response_history": response_history,
                "status": status,
            }
    
    metadata: MetaOapg.properties.metadata
    webhook_id: MetaOapg.properties.webhook_id
    id: MetaOapg.properties.id
    type: 'EventTypeExplicit'
    event_time: MetaOapg.properties.event_time
    url: MetaOapg.properties.url
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_time"]) -> MetaOapg.properties.event_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> 'EventTypeExplicit': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["webhook_id"]) -> MetaOapg.properties.webhook_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_resource"]) -> MetaOapg.properties.event_resource: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_resource_changed_fields"]) -> MetaOapg.properties.event_resource_changed_fields: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["response_history"]) -> MetaOapg.properties.response_history: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["event_time", "id", "metadata", "type", "url", "webhook_id", "event_resource", "event_resource_changed_fields", "response_history", "status", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_time"]) -> MetaOapg.properties.event_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> 'EventTypeExplicit': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["webhook_id"]) -> MetaOapg.properties.webhook_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_resource"]) -> typing.Union[MetaOapg.properties.event_resource, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_resource_changed_fields"]) -> typing.Union[MetaOapg.properties.event_resource_changed_fields, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["response_history"]) -> typing.Union[MetaOapg.properties.response_history, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["event_time", "id", "metadata", "type", "url", "webhook_id", "event_resource", "event_resource_changed_fields", "response_history", "status", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        metadata: typing.Union[MetaOapg.properties.metadata, str, ],
        webhook_id: typing.Union[MetaOapg.properties.webhook_id, str, uuid.UUID, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        type: 'EventTypeExplicit',
        event_time: typing.Union[MetaOapg.properties.event_time, str, datetime, ],
        url: typing.Union[MetaOapg.properties.url, str, ],
        event_resource: typing.Union[MetaOapg.properties.event_resource, str, schemas.Unset] = schemas.unset,
        event_resource_changed_fields: typing.Union[MetaOapg.properties.event_resource_changed_fields, str, schemas.Unset] = schemas.unset,
        response_history: typing.Union[MetaOapg.properties.response_history, list, tuple, schemas.Unset] = schemas.unset,
        status: typing.Union[MetaOapg.properties.status, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'WebhookRequestObject':
        return super().__new__(
            cls,
            *_args,
            metadata=metadata,
            webhook_id=webhook_id,
            id=id,
            type=type,
            event_time=event_time,
            url=url,
            event_resource=event_resource,
            event_resource_changed_fields=event_resource_changed_fields,
            response_history=response_history,
            status=status,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.event_type_explicit import EventTypeExplicit
from synctera_client.model.response_history_item import ResponseHistoryItem



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class TransferResponseBase(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "country_code",
            "created_time",
            "amount",
            "account_id",
            "last_modified_time",
            "external_card_id",
            "merchant",
            "currency",
            "id",
            "customer_id",
            "type",
            "status",
        }
        
        class properties:
            account_id = schemas.UUIDSchema
            amount = schemas.IntSchema
            country_code = schemas.StrSchema
            created_time = schemas.DateTimeSchema
        
            @staticmethod
            def currency() -> typing.Type['CurrencyCode']:
                return CurrencyCode
            customer_id = schemas.UUIDSchema
            external_card_id = schemas.UUIDSchema
            id = schemas.StrSchema
            last_modified_time = schemas.DateTimeSchema
        
            @staticmethod
            def merchant() -> typing.Type['Merchant']:
                return Merchant
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def SUCCEEDED(cls):
                    return cls("SUCCEEDED")
                
                @schemas.classproperty
                def PENDING(cls):
                    return cls("PENDING")
                
                @schemas.classproperty
                def DECLINED(cls):
                    return cls("DECLINED")
                
                @schemas.classproperty
                def CANCELED(cls):
                    return cls("CANCELED")
                
                @schemas.classproperty
                def UNKNOWN(cls):
                    return cls("UNKNOWN")
        
            @staticmethod
            def type() -> typing.Type['TransferType']:
                return TransferType
            transaction_id = schemas.UUIDSchema
            __annotations__ = {
                "account_id": account_id,
                "amount": amount,
                "country_code": country_code,
                "created_time": created_time,
                "currency": currency,
                "customer_id": customer_id,
                "external_card_id": external_card_id,
                "id": id,
                "last_modified_time": last_modified_time,
                "merchant": merchant,
                "status": status,
                "type": type,
                "transaction_id": transaction_id,
            }
    
    country_code: MetaOapg.properties.country_code
    created_time: MetaOapg.properties.created_time
    amount: MetaOapg.properties.amount
    account_id: MetaOapg.properties.account_id
    last_modified_time: MetaOapg.properties.last_modified_time
    external_card_id: MetaOapg.properties.external_card_id
    merchant: 'Merchant'
    currency: 'CurrencyCode'
    id: MetaOapg.properties.id
    customer_id: MetaOapg.properties.customer_id
    type: 'TransferType'
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["country_code"]) -> MetaOapg.properties.country_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created_time"]) -> MetaOapg.properties.created_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> 'CurrencyCode': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["external_card_id"]) -> MetaOapg.properties.external_card_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_modified_time"]) -> MetaOapg.properties.last_modified_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchant"]) -> 'Merchant': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> 'TransferType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_id"]) -> MetaOapg.properties.transaction_id: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["account_id", "amount", "country_code", "created_time", "currency", "customer_id", "external_card_id", "id", "last_modified_time", "merchant", "status", "type", "transaction_id", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["country_code"]) -> MetaOapg.properties.country_code: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created_time"]) -> MetaOapg.properties.created_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> 'CurrencyCode': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["external_card_id"]) -> MetaOapg.properties.external_card_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_modified_time"]) -> MetaOapg.properties.last_modified_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchant"]) -> 'Merchant': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> 'TransferType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_id"]) -> typing.Union[MetaOapg.properties.transaction_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["account_id", "amount", "country_code", "created_time", "currency", "customer_id", "external_card_id", "id", "last_modified_time", "merchant", "status", "type", "transaction_id", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        country_code: typing.Union[MetaOapg.properties.country_code, str, ],
        created_time: typing.Union[MetaOapg.properties.created_time, str, datetime, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        account_id: typing.Union[MetaOapg.properties.account_id, str, uuid.UUID, ],
        last_modified_time: typing.Union[MetaOapg.properties.last_modified_time, str, datetime, ],
        external_card_id: typing.Union[MetaOapg.properties.external_card_id, str, uuid.UUID, ],
        merchant: 'Merchant',
        currency: 'CurrencyCode',
        id: typing.Union[MetaOapg.properties.id, str, ],
        customer_id: typing.Union[MetaOapg.properties.customer_id, str, uuid.UUID, ],
        type: 'TransferType',
        status: typing.Union[MetaOapg.properties.status, str, ],
        transaction_id: typing.Union[MetaOapg.properties.transaction_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TransferResponseBase':
        return super().__new__(
            cls,
            *_args,
            country_code=country_code,
            created_time=created_time,
            amount=amount,
            account_id=account_id,
            last_modified_time=last_modified_time,
            external_card_id=external_card_id,
            merchant=merchant,
            currency=currency,
            id=id,
            customer_id=customer_id,
            type=type,
            status=status,
            transaction_id=transaction_id,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.currency_code import CurrencyCode
from synctera_client.model.merchant import Merchant
from synctera_client.model.transfer_type import TransferType



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class ExternalCardResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "expiration_year",
            "last_four",
            "expiration_month",
            "name",
            "currency",
            "id",
            "customer_id",
            "status",
        }
        
        class properties:
        
            @staticmethod
            def currency() -> typing.Type['CurrencyCode']:
                return CurrencyCode
            customer_id = schemas.UUIDSchema
            expiration_month = schemas.StrSchema
            expiration_year = schemas.StrSchema
            id = schemas.StrSchema
            last_four = schemas.StrSchema
            name = schemas.StrSchema
        
            @staticmethod
            def status() -> typing.Type['ExternalCardStatus']:
                return ExternalCardStatus
            created_time = schemas.DateTimeSchema
            last_modified_time = schemas.DateTimeSchema
        
            @staticmethod
            def verifications() -> typing.Type['ExternalCardVerifications']:
                return ExternalCardVerifications
            __annotations__ = {
                "currency": currency,
                "customer_id": customer_id,
                "expiration_month": expiration_month,
                "expiration_year": expiration_year,
                "id": id,
                "last_four": last_four,
                "name": name,
                "status": status,
                "created_time": created_time,
                "last_modified_time": last_modified_time,
                "verifications": verifications,
            }
    
    expiration_year: MetaOapg.properties.expiration_year
    last_four: MetaOapg.properties.last_four
    expiration_month: MetaOapg.properties.expiration_month
    name: MetaOapg.properties.name
    currency: 'CurrencyCode'
    id: MetaOapg.properties.id
    customer_id: MetaOapg.properties.customer_id
    status: 'ExternalCardStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> 'CurrencyCode': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiration_month"]) -> MetaOapg.properties.expiration_month: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiration_year"]) -> MetaOapg.properties.expiration_year: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_four"]) -> MetaOapg.properties.last_four: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'ExternalCardStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created_time"]) -> MetaOapg.properties.created_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_modified_time"]) -> MetaOapg.properties.last_modified_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verifications"]) -> 'ExternalCardVerifications': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["currency", "customer_id", "expiration_month", "expiration_year", "id", "last_four", "name", "status", "created_time", "last_modified_time", "verifications", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> 'CurrencyCode': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiration_month"]) -> MetaOapg.properties.expiration_month: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiration_year"]) -> MetaOapg.properties.expiration_year: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_four"]) -> MetaOapg.properties.last_four: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'ExternalCardStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created_time"]) -> typing.Union[MetaOapg.properties.created_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_modified_time"]) -> typing.Union[MetaOapg.properties.last_modified_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verifications"]) -> typing.Union['ExternalCardVerifications', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["currency", "customer_id", "expiration_month", "expiration_year", "id", "last_four", "name", "status", "created_time", "last_modified_time", "verifications", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        expiration_year: typing.Union[MetaOapg.properties.expiration_year, str, ],
        last_four: typing.Union[MetaOapg.properties.last_four, str, ],
        expiration_month: typing.Union[MetaOapg.properties.expiration_month, str, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        currency: 'CurrencyCode',
        id: typing.Union[MetaOapg.properties.id, str, ],
        customer_id: typing.Union[MetaOapg.properties.customer_id, str, uuid.UUID, ],
        status: 'ExternalCardStatus',
        created_time: typing.Union[MetaOapg.properties.created_time, str, datetime, schemas.Unset] = schemas.unset,
        last_modified_time: typing.Union[MetaOapg.properties.last_modified_time, str, datetime, schemas.Unset] = schemas.unset,
        verifications: typing.Union['ExternalCardVerifications', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ExternalCardResponse':
        return super().__new__(
            cls,
            *_args,
            expiration_year=expiration_year,
            last_four=last_four,
            expiration_month=expiration_month,
            name=name,
            currency=currency,
            id=id,
            customer_id=customer_id,
            status=status,
            created_time=created_time,
            last_modified_time=last_modified_time,
            verifications=verifications,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.currency_code import CurrencyCode
from synctera_client.model.external_card_status import ExternalCardStatus
from synctera_client.model.external_card_verifications import ExternalCardVerifications



from synctera_client.paths.cash_pickups_cash_pickup_id.get import ApiForget
from synctera_client.paths.cash_pickups_cash_pickup_id.patch import ApiForpatch


class CashPickupsCashPickupId(
    ApiForget,
    ApiForpatch,
):
    pass



from synctera_client.paths.external_cards_external_card_id.get import ApiForget
from synctera_client.paths.external_cards_external_card_id.delete import ApiFordelete
from synctera_client.paths.external_cards_external_card_id.patch import ApiForpatch


class ExternalCardsExternalCardId(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""
import dataclasses
import typing

from urllib3._collections import HTTPHeaderDict


class OpenApiException(Exception):
    """The base exception class for all OpenAPIExceptions"""


class ApiTypeError(OpenApiException, TypeError):
    def __init__(self, msg, path_to_item=None, valid_classes=None,
                 key_type=None):
        """ Raises an exception for TypeErrors

        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (list): a list of keys an indices to get to the
                                 current_item
                                 None if unset
            valid_classes (tuple): the primitive classes that current item
                                   should be an instance of
                                   None if unset
            key_type (bool): False if our value is a value in a dict
                             True if it is a key in a dict
                             False if our item is an item in a list
                             None if unset
        """
        self.path_to_item = path_to_item
        self.valid_classes = valid_classes
        self.key_type = key_type
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiTypeError, self).__init__(full_msg)


class ApiValueError(OpenApiException, ValueError):
    def __init__(self, msg, path_to_item=None):
        """
        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (list) the path to the exception in the
                received_data dict. None if unset
        """

        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiValueError, self).__init__(full_msg)


class ApiAttributeError(OpenApiException, AttributeError):
    def __init__(self, msg, path_to_item=None):
        """
        Raised when an attribute reference or assignment fails.

        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (None/list) the path to the exception in the
                received_data dict
        """
        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiAttributeError, self).__init__(full_msg)


class ApiKeyError(OpenApiException, KeyError):
    def __init__(self, msg, path_to_item=None):
        """
        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (None/list) the path to the exception in the
                received_data dict
        """
        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiKeyError, self).__init__(full_msg)


T = typing.TypeVar("T")


@dataclasses.dataclass
class ApiException(OpenApiException, typing.Generic[T]):
    status: int
    reason: str
    api_response: typing.Optional[T] = None

    @property
    def body(self) -> typing.Union[str, bytes, None]:
        if not self.api_response:
            return None
        return self.api_response.response.data

    @property
    def headers(self) -> typing.Optional[HTTPHeaderDict]:
        if not self.api_response:
            return None
        return self.api_response.response.getheaders()

    def __str__(self):
        """Custom error messages for exception"""
        error_message = "({0})\n"\
                        "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(
                self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message


def render_path(path_to_item):
    """Returns a string representation of a path"""
    result = ""
    for pth in path_to_item:
        if isinstance(pth, int):
            result += "[{0}]".format(pth)
        else:
            result += "['{0}']".format(pth)
    return result



from synctera_client.paths.accounts_account_id_relationships_relationship_id.get import ApiForget
from synctera_client.paths.accounts_account_id_relationships_relationship_id.put import ApiForput
from synctera_client.paths.accounts_account_id_relationships_relationship_id.delete import ApiFordelete


class AccountsAccountIdRelationshipsRelationshipId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

import logging
import ssl
from urllib.parse import urlencode
import typing

import certifi
import urllib3
from urllib3._collections import HTTPHeaderDict

from synctera_client.exceptions import ApiException, ApiValueError


logger = logging.getLogger(__name__)


class RESTClientObject(object):

    def __init__(self, configuration, pools_size=4, maxsize=None):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75  # noqa: E501
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680  # noqa: E501
        # maxsize is the number of requests to host that are allowed in parallel  # noqa: E501
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html  # noqa: E501

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        # ca_certs
        if configuration.ssl_ca_cert:
            ca_certs = configuration.ssl_ca_cert
        else:
            # if not set certificate file, use Mozilla's root certificates.
            ca_certs = certifi.where()

        addition_pool_args = {}
        if configuration.assert_hostname is not None:
            addition_pool_args['assert_hostname'] = configuration.assert_hostname  # noqa: E501

        if configuration.retries is not None:
            addition_pool_args['retries'] = configuration.retries

        if configuration.socket_options is not None:
            addition_pool_args['socket_options'] = configuration.socket_options

        if maxsize is None:
            if configuration.connection_pool_maxsize is not None:
                maxsize = configuration.connection_pool_maxsize
            else:
                maxsize = 4

        # https pool manager
        if configuration.proxy:
            self.pool_manager = urllib3.ProxyManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                proxy_url=configuration.proxy,
                proxy_headers=configuration.proxy_headers,
                **addition_pool_args
            )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                **addition_pool_args
            )

    def request(
        self,
        method: str,
        url: str,
        headers: typing.Optional[HTTPHeaderDict] = None,
        fields: typing.Optional[typing.Tuple[typing.Tuple[str, typing.Any], ...]] = None,
        body: typing.Optional[typing.Union[str, bytes]] = None,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> urllib3.HTTPResponse:
        """Perform requests.

        :param method: http request method
        :param url: http request url
        :param headers: http request headers
        :param body: request body, for other types
        :param fields: request parameters for
                                `application/x-www-form-urlencoded`
                                or `multipart/form-data`
        :param stream: if True, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is False.
        :param timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT',
                          'PATCH', 'OPTIONS']

        if fields and body:
            raise ApiValueError(
                "body parameter cannot be used with fields parameter."
            )

        fields = fields or {}
        headers = headers or {}

        if timeout:
            if isinstance(timeout, (int, float)):  # noqa: E501,F821
                timeout = urllib3.Timeout(total=timeout)
            elif (isinstance(timeout, tuple) and
                  len(timeout) == 2):
                timeout = urllib3.Timeout(connect=timeout[0], read=timeout[1])

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:
                if 'Content-Type' not in headers and body is None:
                    r = self.pool_manager.request(
                        method,
                        url,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers
                    )
                elif headers['Content-Type'] == 'application/x-www-form-urlencoded':  # noqa: E501
                    r = self.pool_manager.request(
                        method, url,
                        body=body,
                        fields=fields,
                        encode_multipart=False,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                elif headers['Content-Type'] == 'multipart/form-data':
                    # must del headers['Content-Type'], or the correct
                    # Content-Type which generated by urllib3 will be
                    # overwritten.
                    del headers['Content-Type']
                    r = self.pool_manager.request(
                        method, url,
                        fields=fields,
                        encode_multipart=True,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                # Pass a `string` parameter directly in the body to support
                # other content types than Json when `body` argument is
                # provided in serialized form
                elif isinstance(body, str) or isinstance(body, bytes):
                    request_body = body
                    r = self.pool_manager.request(
                        method, url,
                        body=request_body,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided
                             arguments. Please check that your arguments match
                             declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(method, url,
                                              preload_content=not stream,
                                              timeout=timeout,
                                              headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        if not stream:
            # log response body
            logger.debug("response body: %s", r.data)

        return r

    def GET(self, url, headers=None, stream=False,
            timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("GET", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            fields=fields)

    def HEAD(self, url, headers=None, stream=False,
             timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("HEAD", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            fields=fields)

    def OPTIONS(self, url, headers=None,
                body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("OPTIONS", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def DELETE(self, url, headers=None, body=None,
               stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("DELETE", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def POST(self, url, headers=None,
             body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("POST", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def PUT(self, url, headers=None,
            body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("PUT", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def PATCH(self, url, headers=None,
              body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("PATCH", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class Document(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def available_versions() -> typing.Type['DocumentVersions']:
                return DocumentVersions
            creation_time = schemas.DateTimeSchema
            description = schemas.StrSchema
        
            @staticmethod
            def encryption() -> typing.Type['Encryption']:
                return Encryption
            file_name = schemas.StrSchema
            id = schemas.UUIDSchema
            is_restricted = schemas.BoolSchema
            last_updated_time = schemas.DateTimeSchema
            metadata = schemas.DictSchema
            name = schemas.StrSchema
            related_resource_id = schemas.UUIDSchema
        
            @staticmethod
            def related_resource_type() -> typing.Type['RelatedResourceType']:
                return RelatedResourceType
            tenant = schemas.StrSchema
        
            @staticmethod
            def type() -> typing.Type['DocumentType']:
                return DocumentType
            version = schemas.IntSchema
            __annotations__ = {
                "available_versions": available_versions,
                "creation_time": creation_time,
                "description": description,
                "encryption": encryption,
                "file_name": file_name,
                "id": id,
                "is_restricted": is_restricted,
                "last_updated_time": last_updated_time,
                "metadata": metadata,
                "name": name,
                "related_resource_id": related_resource_id,
                "related_resource_type": related_resource_type,
                "tenant": tenant,
                "type": type,
                "version": version,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["available_versions"]) -> 'DocumentVersions': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creation_time"]) -> MetaOapg.properties.creation_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["encryption"]) -> 'Encryption': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["file_name"]) -> MetaOapg.properties.file_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_restricted"]) -> MetaOapg.properties.is_restricted: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_updated_time"]) -> MetaOapg.properties.last_updated_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["related_resource_id"]) -> MetaOapg.properties.related_resource_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["related_resource_type"]) -> 'RelatedResourceType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tenant"]) -> MetaOapg.properties.tenant: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> 'DocumentType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["version"]) -> MetaOapg.properties.version: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["available_versions", "creation_time", "description", "encryption", "file_name", "id", "is_restricted", "last_updated_time", "metadata", "name", "related_resource_id", "related_resource_type", "tenant", "type", "version", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["available_versions"]) -> typing.Union['DocumentVersions', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creation_time"]) -> typing.Union[MetaOapg.properties.creation_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["encryption"]) -> typing.Union['Encryption', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["file_name"]) -> typing.Union[MetaOapg.properties.file_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_restricted"]) -> typing.Union[MetaOapg.properties.is_restricted, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_updated_time"]) -> typing.Union[MetaOapg.properties.last_updated_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["related_resource_id"]) -> typing.Union[MetaOapg.properties.related_resource_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["related_resource_type"]) -> typing.Union['RelatedResourceType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tenant"]) -> typing.Union[MetaOapg.properties.tenant, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> typing.Union['DocumentType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["version"]) -> typing.Union[MetaOapg.properties.version, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["available_versions", "creation_time", "description", "encryption", "file_name", "id", "is_restricted", "last_updated_time", "metadata", "name", "related_resource_id", "related_resource_type", "tenant", "type", "version", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        available_versions: typing.Union['DocumentVersions', schemas.Unset] = schemas.unset,
        creation_time: typing.Union[MetaOapg.properties.creation_time, str, datetime, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        encryption: typing.Union['Encryption', schemas.Unset] = schemas.unset,
        file_name: typing.Union[MetaOapg.properties.file_name, str, schemas.Unset] = schemas.unset,
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        is_restricted: typing.Union[MetaOapg.properties.is_restricted, bool, schemas.Unset] = schemas.unset,
        last_updated_time: typing.Union[MetaOapg.properties.last_updated_time, str, datetime, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
        related_resource_id: typing.Union[MetaOapg.properties.related_resource_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        related_resource_type: typing.Union['RelatedResourceType', schemas.Unset] = schemas.unset,
        tenant: typing.Union[MetaOapg.properties.tenant, str, schemas.Unset] = schemas.unset,
        type: typing.Union['DocumentType', schemas.Unset] = schemas.unset,
        version: typing.Union[MetaOapg.properties.version, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Document':
        return super().__new__(
            cls,
            *_args,
            available_versions=available_versions,
            creation_time=creation_time,
            description=description,
            encryption=encryption,
            file_name=file_name,
            id=id,
            is_restricted=is_restricted,
            last_updated_time=last_updated_time,
            metadata=metadata,
            name=name,
            related_resource_id=related_resource_id,
            related_resource_type=related_resource_type,
            tenant=tenant,
            type=type,
            version=version,
            _configuration=_configuration,
            **kwargs,
        )

from synctera_client.model.document_type import DocumentType
from synctera_client.model.document_versions import DocumentVersions
from synctera_client.model.encryption import Encryption
from synctera_client.model.related_resource_type import RelatedResourceType



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class VerificationStatus(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The result of a KYC/KYB verification. One of the following:
* `UNVERIFIED` – verification has not been completed for this customer.
* `PENDING` – verification is in progress for this customer.
* `PROVISIONAL` – partially verified or verified with restrictions.
* `ACCEPTED` – the customer has been verified.
* `REVIEW` – verification has run and issues have been identified and require review.
* `REJECTED` – the customer was rejected and should not be allowed to take certain actions e.g., open an account.

    """
    
    @schemas.classproperty
    def UNVERIFIED(cls):
        return cls("UNVERIFIED")
    
    @schemas.classproperty
    def PENDING(cls):
        return cls("PENDING")
    
    @schemas.classproperty
    def PROVISIONAL(cls):
        return cls("PROVISIONAL")
    
    @schemas.classproperty
    def ACCEPTED(cls):
        return cls("ACCEPTED")
    
    @schemas.classproperty
    def REVIEW(cls):
        return cls("REVIEW")
    
    @schemas.classproperty
    def REJECTED(cls):
        return cls("REJECTED")



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from synctera_client.paths.cards_activate.post import ActivateCard
from synctera_client.paths.cards_images.post import CreateCardImage
from synctera_client.paths.cards_gateways.post import CreateGateway
from synctera_client.paths.cards_card_id.get import GetCard
from synctera_client.paths.cards_card_id_barcodes.get import GetCardBarcode
from synctera_client.paths.cards_images_card_image_id_data.get import GetCardImageData
from synctera_client.paths.cards_images_card_image_id.get import GetCardImageDetails
from synctera_client.paths.cards_card_widget_url.get import GetCardWidgetUrl
from synctera_client.paths.cards_card_id_client_token.post import GetClientAccessToken
from synctera_client.paths.cards_single_use_token.post import GetClientSingleUseToken
from synctera_client.paths.cards_gateways_gateway_id.get import GetGateway
from synctera_client.paths.cards.post import IssueCard
from synctera_client.paths.cards_images.get import ListCardImageDetails
from synctera_client.paths.cards_products.get import ListCardProducts
from synctera_client.paths.cards.get import ListCards
from synctera_client.paths.cards_card_id_changes.get import ListChanges
from synctera_client.paths.cards_gateways.get import ListGateways
from synctera_client.paths.cards_card_id.patch import UpdateCard
from synctera_client.paths.cards_images_card_image_id.patch import UpdateCardImageDetails
from synctera_client.paths.cards_gateways_gateway_id.patch import UpdateGateway
from synctera_client.paths.cards_images_card_image_id_data.post import UploadCardImageData


class CardsApi(
    ActivateCard,
    CreateCardImage,
    CreateGateway,
    GetCard,
    GetCardBarcode,
    GetCardImageData,
    GetCardImageDetails,
    GetCardWidgetUrl,
    GetClientAccessToken,
    GetClientSingleUseToken,
    GetGateway,
    IssueCard,
    ListCardImageDetails,
    ListCardProducts,
    ListCards,
    ListChanges,
    ListGateways,
    UpdateCard,
    UpdateCardImageDetails,
    UpdateGateway,
    UploadCardImageData,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from synctera_client.paths.cards_images_card_image_id.get import ApiForget
from synctera_client.paths.cards_images_card_image_id.patch import ApiForpatch


class CardsImagesCardImageId(
    ApiForget,
    ApiForpatch,
):
    pass



import typing_extensions

from synctera_client.apis.tags import TagValues
from synctera_client.apis.tags.account_products_api import AccountProductsApi
from synctera_client.apis.tags.accounts_api import AccountsApi
from synctera_client.apis.tags.account_templates_api import AccountTemplatesApi
from synctera_client.apis.tags.ach_api import ACHApi
from synctera_client.apis.tags.ach_transaction_simulations_api import ACHTransactionSimulationsApi
from synctera_client.apis.tags.admin_api import AdminApi
from synctera_client.apis.tags.api_keys_api import APIKeysApi
from synctera_client.apis.tags.ban_rules_api import BanRulesApi
from synctera_client.apis.tags.banks_api import BanksApi
from synctera_client.apis.tags.quickstart_api import QuickstartApi
from synctera_client.apis.tags.businesses_api import BusinessesApi
from synctera_client.apis.tags.cards_api import CardsApi
from synctera_client.apis.tags.external_cards_api import ExternalCardsApi
from synctera_client.apis.tags.cash_pickups_alpha_api import CashPickupsAlphaApi
from synctera_client.apis.tags.compliance_rules_api import ComplianceRulesApi
from synctera_client.apis.tags.compliance_searches_api import ComplianceSearchesApi
from synctera_client.apis.tags.customers_api import CustomersApi
from synctera_client.apis.tags.disclosures_api import DisclosuresApi
from synctera_client.apis.tags.disclosures_deprecated_api import DisclosuresDeprecatedApi
from synctera_client.apis.tags.documents_api import DocumentsApi
from synctera_client.apis.tags.stately_api import StatelyApi
from synctera_client.apis.tags.external_accounts_api import ExternalAccountsApi
from synctera_client.apis.tags.history_api import HistoryApi
from synctera_client.apis.tags.identity_api import IdentityApi
from synctera_client.apis.tags.internal_accounts_api import InternalAccountsApi
from synctera_client.apis.tags.kyc_verification_deprecated_api import KYCVerificationDeprecatedApi
from synctera_client.apis.tags.middesk_api import MiddeskApi
from synctera_client.apis.tags.monitoring_api import MonitoringApi
from synctera_client.apis.tags.notes_api import NotesApi
from synctera_client.apis.tags.partners_api import PartnersApi
from synctera_client.apis.tags.party_groups_api import PartyGroupsApi
from synctera_client.apis.tags.cronut_api import CronutApi
from synctera_client.apis.tags.persons_api import PersonsApi
from synctera_client.apis.tags.posting_dates_api import PostingDatesApi
from synctera_client.apis.tags.remote_check_deposit_api import RemoteCheckDepositApi
from synctera_client.apis.tags.rdc_config_api import RDCConfigApi
from synctera_client.apis.tags.relationships_api import RelationshipsApi
from synctera_client.apis.tags.roles_api import RolesApi
from synctera_client.apis.tags.spend_controls_beta_api import SpendControlsBetaApi
from synctera_client.apis.tags.tenant_configs_api import TenantConfigsApi
from synctera_client.apis.tags.card_transaction_simulations_api import CardTransactionSimulationsApi
from synctera_client.apis.tags.transaction_risk_api import TransactionRiskApi
from synctera_client.apis.tags.transactions_api import TransactionsApi
from synctera_client.apis.tags.users_api import UsersApi
from synctera_client.apis.tags.egress_gateway_vendor_secret_crudapi_api import EgressGatewayVendorSecretCRUDAPIApi
from synctera_client.apis.tags.kyckyb_verifications_api import KYCKYBVerificationsApi
from synctera_client.apis.tags.waitlist_api import WaitlistApi
from synctera_client.apis.tags.watchlist_deprecated_api import WatchlistDeprecatedApi
from synctera_client.apis.tags.egress_gateway_webhook_secret_crudapi_api import EgressGatewayWebhookSecretCRUDAPIApi
from synctera_client.apis.tags.card_webhook_simulations_api import CardWebhookSimulationsApi
from synctera_client.apis.tags.webhooks_api import WebhooksApi
from synctera_client.apis.tags.wires_alpha_api import WiresAlphaApi
from synctera_client.apis.tags.digital_wallet_tokens_api import DigitalWalletTokensApi
from synctera_client.apis.tags.internal_transfer_api import InternalTransferApi
from synctera_client.apis.tags.payment_schedules_api import PaymentSchedulesApi
from synctera_client.apis.tags.remote_check_deposit_beta_api import RemoteCheckDepositBetaApi
from synctera_client.apis.tags.sandbox_wipe_alpha_api import SandboxWipeAlphaApi
from synctera_client.apis.tags.statements_api import StatementsApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.ACCOUNT_PRODUCTS: AccountProductsApi,
        TagValues.ACCOUNTS: AccountsApi,
        TagValues.ACCOUNT_TEMPLATES: AccountTemplatesApi,
        TagValues.ACH: ACHApi,
        TagValues.ACH_TRANSACTION_SIMULATIONS: ACHTransactionSimulationsApi,
        TagValues.ADMIN: AdminApi,
        TagValues.API_KEYS: APIKeysApi,
        TagValues.BAN_RULES: BanRulesApi,
        TagValues.BANKS: BanksApi,
        TagValues.QUICKSTART: QuickstartApi,
        TagValues.BUSINESSES: BusinessesApi,
        TagValues.CARDS: CardsApi,
        TagValues.EXTERNAL_CARDS: ExternalCardsApi,
        TagValues.CASH_PICKUPS_ALPHA: CashPickupsAlphaApi,
        TagValues.COMPLIANCE_RULES: ComplianceRulesApi,
        TagValues.COMPLIANCE_SEARCHES: ComplianceSearchesApi,
        TagValues.CUSTOMERS: CustomersApi,
        TagValues.DISCLOSURES: DisclosuresApi,
        TagValues.DISCLOSURES_DEPRECATED: DisclosuresDeprecatedApi,
        TagValues.DOCUMENTS: DocumentsApi,
        TagValues.STATELY: StatelyApi,
        TagValues.EXTERNAL_ACCOUNTS: ExternalAccountsApi,
        TagValues.HISTORY: HistoryApi,
        TagValues.IDENTITY: IdentityApi,
        TagValues.INTERNAL_ACCOUNTS: InternalAccountsApi,
        TagValues.KYC_VERIFICATION_DEPRECATED: KYCVerificationDeprecatedApi,
        TagValues.MIDDESK: MiddeskApi,
        TagValues.MONITORING: MonitoringApi,
        TagValues.NOTES: NotesApi,
        TagValues.PARTNERS: PartnersApi,
        TagValues.PARTY_GROUPS: PartyGroupsApi,
        TagValues.CRONUT: CronutApi,
        TagValues.PERSONS: PersonsApi,
        TagValues.POSTING_DATES: PostingDatesApi,
        TagValues.REMOTE_CHECK_DEPOSIT: RemoteCheckDepositApi,
        TagValues.RDC_CONFIG: RDCConfigApi,
        TagValues.RELATIONSHIPS: RelationshipsApi,
        TagValues.ROLES: RolesApi,
        TagValues.SPEND_CONTROLS_BETA: SpendControlsBetaApi,
        TagValues.TENANT_CONFIGS: TenantConfigsApi,
        TagValues.CARD_TRANSACTION_SIMULATIONS: CardTransactionSimulationsApi,
        TagValues.TRANSACTION_RISK: TransactionRiskApi,
        TagValues.TRANSACTIONS: TransactionsApi,
        TagValues.USERS: UsersApi,
        TagValues.EGRESS_GATEWAY_VENDOR_SECRET_CRUD_API: EgressGatewayVendorSecretCRUDAPIApi,
        TagValues.KYC_KYB_VERIFICATIONS: KYCKYBVerificationsApi,
        TagValues.WAITLIST: WaitlistApi,
        TagValues.WATCHLIST_DEPRECATED: WatchlistDeprecatedApi,
        TagValues.EGRESS_GATEWAY_WEBHOOK_SECRET_CRUD_API: EgressGatewayWebhookSecretCRUDAPIApi,
        TagValues.CARD_WEBHOOK_SIMULATIONS: CardWebhookSimulationsApi,
        TagValues.WEBHOOKS: WebhooksApi,
        TagValues.WIRES_ALPHA: WiresAlphaApi,
        TagValues.DIGITAL_WALLET_TOKENS: DigitalWalletTokensApi,
        TagValues.INTERNAL_TRANSFER: InternalTransferApi,
        TagValues.PAYMENT_SCHEDULES: PaymentSchedulesApi,
        TagValues.REMOTE_CHECK_DEPOSIT_BETA: RemoteCheckDepositBetaApi,
        TagValues.SANDBOX_WIPE_ALPHA: SandboxWipeAlphaApi,
        TagValues.STATEMENTS: StatementsApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.ACCOUNT_PRODUCTS: AccountProductsApi,
        TagValues.ACCOUNTS: AccountsApi,
        TagValues.ACCOUNT_TEMPLATES: AccountTemplatesApi,
        TagValues.ACH: ACHApi,
        TagValues.ACH_TRANSACTION_SIMULATIONS: ACHTransactionSimulationsApi,
        TagValues.ADMIN: AdminApi,
        TagValues.API_KEYS: APIKeysApi,
        TagValues.BAN_RULES: BanRulesApi,
        TagValues.BANKS: BanksApi,
        TagValues.QUICKSTART: QuickstartApi,
        TagValues.BUSINESSES: BusinessesApi,
        TagValues.CARDS: CardsApi,
        TagValues.EXTERNAL_CARDS: ExternalCardsApi,
        TagValues.CASH_PICKUPS_ALPHA: CashPickupsAlphaApi,
        TagValues.COMPLIANCE_RULES: ComplianceRulesApi,
        TagValues.COMPLIANCE_SEARCHES: ComplianceSearchesApi,
        TagValues.CUSTOMERS: CustomersApi,
        TagValues.DISCLOSURES: DisclosuresApi,
        TagValues.DISCLOSURES_DEPRECATED: DisclosuresDeprecatedApi,
        TagValues.DOCUMENTS: DocumentsApi,
        TagValues.STATELY: StatelyApi,
        TagValues.EXTERNAL_ACCOUNTS: ExternalAccountsApi,
        TagValues.HISTORY: HistoryApi,
        TagValues.IDENTITY: IdentityApi,
        TagValues.INTERNAL_ACCOUNTS: InternalAccountsApi,
        TagValues.KYC_VERIFICATION_DEPRECATED: KYCVerificationDeprecatedApi,
        TagValues.MIDDESK: MiddeskApi,
        TagValues.MONITORING: MonitoringApi,
        TagValues.NOTES: NotesApi,
        TagValues.PARTNERS: PartnersApi,
        TagValues.PARTY_GROUPS: PartyGroupsApi,
        TagValues.CRONUT: CronutApi,
        TagValues.PERSONS: PersonsApi,
        TagValues.POSTING_DATES: PostingDatesApi,
        TagValues.REMOTE_CHECK_DEPOSIT: RemoteCheckDepositApi,
        TagValues.RDC_CONFIG: RDCConfigApi,
        TagValues.RELATIONSHIPS: RelationshipsApi,
        TagValues.ROLES: RolesApi,
        TagValues.SPEND_CONTROLS_BETA: SpendControlsBetaApi,
        TagValues.TENANT_CONFIGS: TenantConfigsApi,
        TagValues.CARD_TRANSACTION_SIMULATIONS: CardTransactionSimulationsApi,
        TagValues.TRANSACTION_RISK: TransactionRiskApi,
        TagValues.TRANSACTIONS: TransactionsApi,
        TagValues.USERS: UsersApi,
        TagValues.EGRESS_GATEWAY_VENDOR_SECRET_CRUD_API: EgressGatewayVendorSecretCRUDAPIApi,
        TagValues.KYC_KYB_VERIFICATIONS: KYCKYBVerificationsApi,
        TagValues.WAITLIST: WaitlistApi,
        TagValues.WATCHLIST_DEPRECATED: WatchlistDeprecatedApi,
        TagValues.EGRESS_GATEWAY_WEBHOOK_SECRET_CRUD_API: EgressGatewayWebhookSecretCRUDAPIApi,
        TagValues.CARD_WEBHOOK_SIMULATIONS: CardWebhookSimulationsApi,
        TagValues.WEBHOOKS: WebhooksApi,
        TagValues.WIRES_ALPHA: WiresAlphaApi,
        TagValues.DIGITAL_WALLET_TOKENS: DigitalWalletTokensApi,
        TagValues.INTERNAL_TRANSFER: InternalTransferApi,
        TagValues.PAYMENT_SCHEDULES: PaymentSchedulesApi,
        TagValues.REMOTE_CHECK_DEPOSIT_BETA: RemoteCheckDepositBetaApi,
        TagValues.SANDBOX_WIPE_ALPHA: SandboxWipeAlphaApi,
        TagValues.STATEMENTS: StatementsApi,
    }
)



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.43.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class ExternalAccountLinkToken(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "country_codes",
            "language",
            "type",
            "client_name",
        }
        
        class properties:
            client_name = schemas.StrSchema
            
            
            class country_codes(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    min_items = 1
                    
                    
                    class items(
                        schemas.EnumBase,
                        schemas.StrSchema
                    ):
                    
                    
                        class MetaOapg:
                            enum_value_to_name = {
                                "US": "US",
                            }
                        
                        @schemas.classproperty
                        def US(cls):
                            return cls("US")
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'country_codes':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class language(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "EN": "EN",
                        "FR": "FR",
                        "ES": "ES",
                        "NL": "NL",
                        "DE": "DE",
                    }
                
                @schemas.classproperty
                def EN(cls):
                    return cls("EN")
                
                @schemas.classproperty
                def FR(cls):
                    return cls("FR")
                
                @schemas.classproperty
                def ES(cls):
                    return cls("ES")
                
                @schemas.classproperty
                def NL(cls):
                    return cls("NL")
                
                @schemas.classproperty
                def DE(cls):
                    return cls("DE")
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "DEPOSITORY": "DEPOSITORY",
                        "CREDIT": "CREDIT",
                        "INVESTMENT": "INVESTMENT",
                        "MICRO_DEPOSIT": "MICRO_DEPOSIT",
                    }
                
                @schemas.classproperty
                def DEPOSITORY(cls):
                    return cls("DEPOSITORY")
                
                @schemas.classproperty
                def CREDIT(cls):
                    return cls("CREDIT")
                
                @schemas.classproperty
                def INVESTMENT(cls):
                    return cls("INVESTMENT")
                
                @schemas.classproperty
                def MICRO_DEPOSIT(cls):
                    return cls("MICRO_DEPOSIT")
            business_id = schemas.UUIDSchema
            customer_id = schemas.UUIDSchema
            expiration = schemas.DateTimeSchema
            link_customization_name = schemas.StrSchema
            link_token = schemas.StrSchema
            redirect_uri = schemas.StrSchema
            request_id = schemas.StrSchema
            
            
            class sdk_type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "WEB": "WEB",
                        "IOS": "IOS",
                        "ANDROID": "ANDROID",
                    }
                
                @schemas.classproperty
                def WEB(cls):
                    return cls("WEB")
                
                @schemas.classproperty
                def IOS(cls):
                    return cls("IOS")
                
                @schemas.classproperty
                def ANDROID(cls):
                    return cls("ANDROID")
            vendor_access_token = schemas.StrSchema
            
            
            class vendor_institution_id(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    min_length = 1
            verify_owner = schemas.BoolSchema
            __annotations__ = {
                "client_name": client_name,
                "country_codes": country_codes,
                "language": language,
                "type": type,
                "business_id": business_id,
                "customer_id": customer_id,
                "expiration": expiration,
                "link_customization_name": link_customization_name,
                "link_token": link_token,
                "redirect_uri": redirect_uri,
                "request_id": request_id,
                "sdk_type": sdk_type,
                "vendor_access_token": vendor_access_token,
                "vendor_institution_id": vendor_institution_id,
                "verify_owner": verify_owner,
            }
    
    country_codes: MetaOapg.properties.country_codes
    language: MetaOapg.properties.language
    type: MetaOapg.properties.type
    client_name: MetaOapg.properties.client_name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["client_name"]) -> MetaOapg.properties.client_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["country_codes"]) -> MetaOapg.properties.country_codes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["language"]) -> MetaOapg.properties.language: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["business_id"]) -> MetaOapg.properties.business_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer_id"]) -> MetaOapg.properties.customer_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiration"]) -> MetaOapg.properties.expiration: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["link_customization_name"]) -> MetaOapg.properties.link_customization_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["link_token"]) -> MetaOapg.properties.link_token: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["redirect_uri"]) -> MetaOapg.properties.redirect_uri: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["request_id"]) -> MetaOapg.properties.request_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sdk_type"]) -> MetaOapg.properties.sdk_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["vendor_access_token"]) -> MetaOapg.properties.vendor_access_token: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["vendor_institution_id"]) -> MetaOapg.properties.vendor_institution_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verify_owner"]) -> MetaOapg.properties.verify_owner: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["client_name", "country_codes", "language", "type", "business_id", "customer_id", "expiration", "link_customization_name", "link_token", "redirect_uri", "request_id", "sdk_type", "vendor_access_token", "vendor_institution_id", "verify_owner", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["client_name"]) -> MetaOapg.properties.client_name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["country_codes"]) -> MetaOapg.properties.country_codes: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["language"]) -> MetaOapg.properties.language: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["business_id"]) -> typing.Union[MetaOapg.properties.business_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer_id"]) -> typing.Union[MetaOapg.properties.customer_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiration"]) -> typing.Union[MetaOapg.properties.expiration, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["link_customization_name"]) -> typing.Union[MetaOapg.properties.link_customization_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["link_token"]) -> typing.Union[MetaOapg.properties.link_token, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["redirect_uri"]) -> typing.Union[MetaOapg.properties.redirect_uri, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["request_id"]) -> typing.Union[MetaOapg.properties.request_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sdk_type"]) -> typing.Union[MetaOapg.properties.sdk_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["vendor_access_token"]) -> typing.Union[MetaOapg.properties.vendor_access_token, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["vendor_institution_id"]) -> typing.Union[MetaOapg.properties.vendor_institution_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verify_owner"]) -> typing.Union[MetaOapg.properties.verify_owner, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["client_name", "country_codes", "language", "type", "business_id", "customer_id", "expiration", "link_customization_name", "link_token", "redirect_uri", "request_id", "sdk_type", "vendor_access_token", "vendor_institution_id", "verify_owner", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        country_codes: typing.Union[MetaOapg.properties.country_codes, list, tuple, ],
        language: typing.Union[MetaOapg.properties.language, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        client_name: typing.Union[MetaOapg.properties.client_name, str, ],
        business_id: typing.Union[MetaOapg.properties.business_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        customer_id: typing.Union[MetaOapg.properties.customer_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        expiration: typing.Union[MetaOapg.properties.expiration, str, datetime, schemas.Unset] = schemas.unset,
        link_customization_name: typing.Union[MetaOapg.properties.link_customization_name, str, schemas.Unset] = schemas.unset,
        link_token: typing.Union[MetaOapg.properties.link_token, str, schemas.Unset] = schemas.unset,
        redirect_uri: typing.Union[MetaOapg.properties.redirect_uri, str, schemas.Unset] = schemas.unset,
        request_id: typing.Union[MetaOapg.properties.request_id, str, schemas.Unset] = schemas.unset,
        sdk_type: typing.Union[MetaOapg.properties.sdk_type, str, schemas.Unset] = schemas.unset,
        vendor_access_token: typing.Union[MetaOapg.properties.vendor_access_token, str, schemas.Unset] = schemas.unset,
        vendor_institution_id: typing.Union[MetaOapg.properties.vendor_institution_id, str, schemas.Unset] = schemas.unset,
        verify_owner: typing.Union[MetaOapg.properties.verify_owner, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ExternalAccountLinkToken':
        return super().__new__(
            cls,
            *_args,
            country_codes=country_codes,
            language=language,
            type=type,
            client_name=client_name,
            business_id=business_id,
            customer_id=customer_id,
            expiration=expiration,
            link_customization_name=link_customization_name,
            link_token=link_token,
            redirect_uri=redirect_uri,
            request_id=request_id,
            sdk_type=sdk_type,
            vendor_access_token=vendor_access_token,
            vendor_institution_id=vendor_institution_id,
            verify_owner=verify_owner,
            _configuration=_configuration,
            **kwargs,
        )



from synctera_client.paths.monitoring_subscriptions.get import ApiForget
from synctera_client.paths.monitoring_subscriptions.post import ApiForpost


class MonitoringSubscriptions(
    ApiForget,
    ApiForpost,
):
    pass
